Bonjour, 

Vous trouverez dans le dossier src tous les fichiers python necessaire pour compiler le projet.
Pensez a taper la commande "pip install -r requirements.txt" s'il vous manque des dependances
pour compiler le projet.


